#!/bin/bash

# pv image fuse script
# It uses pv, align_image_stack (from hugin) and exiftool (from Phil Harvey)
# Remove the last 7 lines if you do not use/have exiftool
# version 1.0, hvdw, 20210313

AIS="/usr/local/bin/align_image_stack"
PV="/usr/local/bin/pv"
ET="/usr/local/bin/exiftool"

Info () {
        printf "* First give the target file name like \"<path>/mypvfused.jpg\" or \"<path>/mypvfused.tif\" or \"<path>/mypvfused.exr\"\n"
        printf "* Then give the input files. That can be as \"*.jpg\", or as \"one.jpg 2.jpg 3.jpg\"\n"
        printf "* Examples:\n* /path/to/pvimagefuser.sh mypvfused.jpg br1.jpg br2.jpg br3.jpg\n"
        printf "* Or:\n* /path/to/pvimagefuser.sh mypvfused.exr *.jpg\n\n"
        exit
}


########################################################################
## main part ##
# No output given?
if [ "$1" = "" ]
then
    Info;
fi
OUTPUT=$1
PREFIX=$(echo $OUTPUT | cut -d"(" -f2 | cut -d"." -f1)
SUFFIX=$(echo $OUTPUT | cut -d"(" -f2 | cut -d"." -f2)
PTO=$(echo $OUTPUT | cut -d"(" -f2 | cut -d"." -f1)".pto"
# Now shift our parameters to exclude our to be created fused image from the image processing
shift;

printf "\n\n* Running align_image_stack on our images\n\n"

align_image_stack --gpu -p "${PTO}" -v $@
printf "\n\n* Done with ais; now running pv on our aligned images\n\n"
${PV} -W \
             --blending=hdr \
             --snapshot_like_source=yes \
             --snapshot_facet=1 \
             --snapshot_extension=$SUFFIX \
             --aeb_auto_brightness=yes \
             --next_after_fusion=yes \
             --build_pyramids=no \
             --quality_interpolator_degree=1 \
             "${PTO}"

# If we named our image "mypvfused.jpg", pv will create "mypvfused.pto.pv.1.fused.jpg"
# So we will first rename it to our desired name
mv "${PTO}.pv.1.fused.${SUFFIX}" "${OUTPUT}"

# As exiftool can't handle exr images we do need to check for these
if [[ ! ( "$SUFFIX" == "exr" || "$SUFFIX" == "EXR" ) ]];
then  
  printf "\n\nFinally running exiftool to copy the metadata from our first image to our fused image \"${OUTPUT}\"\n\n"
  ${ET} -overwrite_original -TagsFromFile $2 "${OUTPUT}"
  ${ET} -v "-DateTimeOriginal>FileModifyDate" "${OUTPUT}"
fi